==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/iotoperationsmq/kotlin/inputs/BrokerAuthenticatorMethodX509Args.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.iotoperationsmq.kotlin.inputs

import com.pulumi.azurenative.iotoperationsmq.inputs.BrokerAuthenticatorMethodX509Args.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * X509 for BrokerAuthentication.
 * @property attributes K8S Secret name to mount for username and password.
 * @property trustedClientCaCertConfigMap Trusted client ca cert config map.
 */
public data class BrokerAuthenticatorMethodX509Args(
    public val attributes: Output<BrokerAuthenticatorMethodX509AttributesArgs>? = null,
    public val trustedClientCaCertConfigMap: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.iotoperationsmq.inputs.BrokerAuthenticatorMethodX509Args> {
    override fun toJava():
        com.pulumi.azurenative.iotoperationsmq.inputs.BrokerAuthenticatorMethodX509Args =
        com.pulumi.azurenative.iotoperationsmq.inputs.BrokerAuthenticatorMethodX509Args.builder()
            .attributes(attributes?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .trustedClientCaCertConfigMap(trustedClientCaCertConfigMap?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [BrokerAuthenticatorMethodX509Args].
 */
@PulumiTagMarker
public class BrokerAuthenticatorMethodX509ArgsBuilder internal constructor() {
    private var attributes: Output<BrokerAuthenticatorMethodX509AttributesArgs>? = null

    private var trustedClientCaCertConfigMap: Output<String>? = null

    /**
     * @param value K8S Secret name to mount for username and password.
     */
    @JvmName("frodafqmvfqsslsc")
    public suspend fun attributes(`value`: Output<BrokerAuthenticatorMethodX509AttributesArgs>) {
        this.attributes = value
    }

    /**
     * @param value Trusted client ca cert config map.
     */
    @JvmName("ktmcpvhexqtusxkt")
    public suspend fun trustedClientCaCertConfigMap(`value`: Output<String>) {
        this.trustedClientCaCertConfigMap = value
    }

    /**
     * @param value K8S Secret name to mount for username and password.
     */
    @JvmName("ivuwmmnphyuwvljg")
    public suspend fun attributes(`value`: BrokerAuthenticatorMethodX509AttributesArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.attributes = mapped
    }

    /**
     * @param argument K8S Secret name to mount for username and password.
     */
    @JvmName("bwhdlwpnehmtddne")
    public suspend
    fun attributes(argument: suspend BrokerAuthenticatorMethodX509AttributesArgsBuilder.() -> Unit) {
        val toBeMapped = BrokerAuthenticatorMethodX509AttributesArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.attributes = mapped
    }

    /**
     * @param value Trusted client ca cert config map.
     */
    @JvmName("hmrrtheelievmjil")
    public suspend fun trustedClientCaCertConfigMap(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.trustedClientCaCertConfigMap = mapped
    }

    internal fun build(): BrokerAuthenticatorMethodX509Args = BrokerAuthenticatorMethodX509Args(
        attributes = attributes,
        trustedClientCaCertConfigMap = trustedClientCaCertConfigMap,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/iotoperationsmq/kotlin/inputs/BrokerAuthenticatorMethodX509Args.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.iotoperationsmq.kotlin.inputs

import com.pulumi.azurenative.iotoperationsmq.inputs.BrokerAuthenticatorMethodX509Args.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * X509 for BrokerAuthentication.
 * @property attributes K8S Secret name to mount for username and password.
 * @property trustedClientCaCertConfigMap Trusted client ca cert config map.
 */
public data class BrokerAuthenticatorMethodX509Args(
    public val attributes: Output<BrokerAuthenticatorMethodX509AttributesArgs>? = null,
    public val trustedClientCaCertConfigMap: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.iotoperationsmq.inputs.BrokerAuthenticatorMethodX509Args> {
    override fun toJava():
        com.pulumi.azurenative.iotoperationsmq.inputs.BrokerAuthenticatorMethodX509Args =
        com.pulumi.azurenative.iotoperationsmq.inputs.BrokerAuthenticatorMethodX509Args.builder()
            .attributes(attributes?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .trustedClientCaCertConfigMap(trustedClientCaCertConfigMap?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [BrokerAuthenticatorMethodX509Args].
 */
@PulumiTagMarker
public class BrokerAuthenticatorMethodX509ArgsBuilder internal constructor() {
    private var attributes: Output<BrokerAuthenticatorMethodX509AttributesArgs>? = null

    private var trustedClientCaCertConfigMap: Output<String>? = null

    /**
     * @param value K8S Secret name to mount for username and password.
     */
    @JvmName("blaaxpfpskvaqvcq")
    public suspend fun attributes(`value`: Output<BrokerAuthenticatorMethodX509AttributesArgs>) {
        this.attributes = value
    }

    /**
     * @param value Trusted client ca cert config map.
     */
    @JvmName("gxjkspywmuosmyry")
    public suspend fun trustedClientCaCertConfigMap(`value`: Output<String>) {
        this.trustedClientCaCertConfigMap = value
    }

    /**
     * @param value K8S Secret name to mount for username and password.
     */
    @JvmName("jdvvmgjqqpepdirw")
    public suspend fun attributes(`value`: BrokerAuthenticatorMethodX509AttributesArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.attributes = mapped
    }

    /**
     * @param argument K8S Secret name to mount for username and password.
     */
    @JvmName("yrsewvqeykapbpov")
    public suspend
    fun attributes(argument: suspend BrokerAuthenticatorMethodX509AttributesArgsBuilder.() -> Unit) {
        val toBeMapped = BrokerAuthenticatorMethodX509AttributesArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.attributes = mapped
    }

    /**
     * @param value Trusted client ca cert config map.
     */
    @JvmName("ukjlqscjgwirbhun")
    public suspend fun trustedClientCaCertConfigMap(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.trustedClientCaCertConfigMap = mapped
    }

    internal fun build(): BrokerAuthenticatorMethodX509Args = BrokerAuthenticatorMethodX509Args(
        attributes = attributes,
        trustedClientCaCertConfigMap = trustedClientCaCertConfigMap,
    )
}
